/* Upgrade Artwork Tracker database from v1 to v2 */

begin exclusive transaction;

/* Copy existing data into new tables */
create table old_version as select * from version;
create table old_client as select * from client;
create table old_submission as select * from submission;

/* Drop old tables */
drop table version;
drop table client;
drop table submission;

/* Create new artist table */
CREATE TABLE artist (pk INTEGER PRIMARY KEY, name CHAR(200));

/* Create new version table */
CREATE TABLE version (pk INTEGER PRIMARY KEY, version_num INTEGER, creation_date REAL, db_type INTEGER, comments CHAR(100), app_identifier INTEGER, app_version REAL, export_date REAL, num_artworks INTEGER, num_clients INTEGER, num_submissions INTEGER, num_mediums INTEGER, num_images INTEGER, num_artists INTEGER);

/* Create new client table with new client_type field */
CREATE TABLE client (pk INTEGER PRIMARY KEY, company CHAR(200), commission REAL, payrate REAL, deadline REAL, response_time INTEGER, response_time_units INTEGER, status BOOLEAN, contact CHAR(200), address CHAR(5000), web CHAR(200), email CHAR(200), phone CHAR(200), fax CHAR(200), notes CHAR(5000), client_type INTEGER);

/* Create new submission table with new submission_type and exhibited fields */
CREATE TABLE submission (pk INTEGER PRIMARY KEY, artwork_key INTEGER, client_key INTEGER, sent_date REAL, response INTEGER, response_date REAL, state INTEGER, income REAL, valid_due_date BOOLEAN, response_due_date REAL, notes CHAR(5000), release_signed BOOLEAN, submission_type INTEGER, exhibited BOOLEAN);

/* Copy old data back into tables */
insert into version (pk, version_num, creation_date, db_type, comments, app_identifier, app_version, export_date, num_artworks, num_clients, num_submissions, num_mediums, num_images) select pk, version_num, creation_date, db_type, comments, app_identifier, app_version, export_date, num_artworks, num_clients, num_submissions, num_mediums, num_images from old_version;

insert into client (pk, company, commission, payrate, deadline, response_time, response_time_units, status, contact, address, web, email, phone, fax, notes) select pk, company, commission, payrate, deadline, response_time, response_time_units, status, contact, address, web, email, phone, fax, notes from old_client;

insert into submission (pk, artwork_key, client_key, sent_date, response, response_date, state, income, valid_due_date, response_due_date, notes, release_signed) select pk, artwork_key, client_key, sent_date, response, response_date, state, income, valid_due_date, response_due_date, notes, release_signed from old_submission;

/* Update database version number */
update version set version_num = 2;

/* Remove temporary tables */
drop table old_client;
drop table old_submission;
drop table old_version;

commit;
